package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"````````!``````````$BQ````
M`````````$``.``)`$``'0`<``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````$B?````````2)\`````````
M`"````````$````&````6*L```````!8JR```````%BK(```````R`0`````
M``!0%0``````````(````````@````8```"(JP```````(BK(```````B*L@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````>)@```````!XF````````'B8````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````%BK````````6*L@``````!8JR``
M`````*@$````````J`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50!H]<+-O1"#A?A;MMJ=[1\_<D\7#A$```!%````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!%````
M20```$T```!.````50```%8```!8````7````%T`````````7P```&(```!C
M````9```````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````)0$``!(`````
M````````````````````$`(``!(`````````````````````````CP(``!(`
M````````````````````````9`(``!(`````````````````````````$0``
M`"``````````````````````````E@(``!(`````````````````````````
M&P,``!(`````````````````````````R````!(`````````````````````
M````JP(``!(`````````````````````````EP$``!(`````````````````
M`````````P,``!(`````````````````````````^P(``!(`````````````
M````````````F````!(`````````````````````````Z@,``!(`````````
M````````````````(`$``!(`````````````````````````QP(``!(`````
M````````````````````N0(``!(`````````````````````````?@(``!(`
M````````````````````````%`,``!(`````````````````````````,0,`
M`!(`````````````````````````>P$``!(`````````````````````````
M20$``!(`````````````````````````U@```!(`````````````````````
M````Q0$``!(`````````````````````````/0(``!(`````````````````
M````````=0(``!(`````````````````````````30(``!(`````````````
M````````````;`(``!(`````````````````````````L@$``!(`````````
M````````````````I`(``!(`````````````````````````"P(``!(`````
M````````````````````=0,``!(`````````````````````````;@,``!(`
M````````````````````````5P$``!(`````````````````````````)`,`
M`!(`````````````````````````+0```"``````````````````````````
MVP(``!(`````````````````````````>````!(`````````````````````
M````*0(``!(`````````````````````````O@$``!(`````````````````
M````````IP```!(`````````````````````````LP```!(`````````````
M````````````<`$``!(`````````````````````````-@$``!(`````````
M````````````````:@```!(`````````````````````````*@$``!(`````
M````````````````````X@(``!(`````````````````````````IP$``!(`
M````````````````````````!`$``!(`````````````````````````G`(`
M`!(`````````````````````````!`(``!(`````````````````````````
M7P,``!(`````````````````````````.`,``!(`````````````````````
M````B0$``!(`````````````````````````AP```!(`````````````````
M````````9P,``!(`````````````````````````L@(``!(`````````````
M````````````/````"``````````````````````````Z````!(`````````
M````````````````9P$``!(`````````````````````````\`(``!(`````
M````````````````````7P(``!(`````````````````````````(0(``!(`
M````````````````````````S0(``!(`````````````````````````4```
M`"``````````````````````````0@,``"(`````````````````````````
MP`(``!(`````````````````````````40,``!(`````````````````````
M````\P,``!(`#@``6````````'8`````````P0,``!(`#P`460``````````
M````````&`0``!(`#@#@1P```````%0,````````@@,``!(`#@"0'@``````
M`"0"````````QP,``!(`#@``00````````4`````````A@0``!(`#@`000``
M``````D"````````@`0``!(`"P"H&@``````````````````LP0``!(`#@!`
M5````````+D#````````I@,``!``&@`@L"``````````````````_P,``!(`
M#@`@0P```````"0`````````,@0``!$`$``@60````````0`````````T`$`
M`!$`%@!PJR```````!,`````````L@,``!``&@"HP"``````````````````
M?@0``!(`#@"P/P```````#``````````DP0``!(`#@#P1@```````.D`````
M````I00``!(`#@!`1@```````'D`````````)00``!``&0``L"``````````
M````````#`0``!(`#@!00P```````.,`````````AP,``!$`&@!(L"``````
M``@`````````GP,``!``&0`@L"``````````````````B`,``"$`&@!(L"``
M``````@`````````9P0``!$`&0`8L"````````@`````````#0,``!$`&@!@
ML"````````@`````````MP,``!(`#@`060````````(`````````5P0``!(`
M#@"@6````````&4`````````*P0``!(`#@#`(````````"L`````````)P0`
M`"``&0``L"``````````````````%0$``!$`&@`@L"````````0`````````
MB0,``"$`&@!(L"````````@`````````V`,``!(`#@#`1@```````"0`````
M````000``!(`#@`P0````````,$`````````]P```!$`&@!`L"````````$`
M````````<00``!(`#@!`1````````/(!`````````&QI8G!E<FPN<V\N-2XR
M-@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!0
M3%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D
M+G-O+C``;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?
M871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K
M7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`
M<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC
M<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T
M`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QI
M8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R
M7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#
M7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXT`````@`#``(``@````(``@````(````"``(````"`````@`"``0`
M`@`"`````````````P`"``4``@````(``P`"``(````&````!P````,``@``
M```````````````&```````"``,``@`"```````"``(``````````@`"``,`
M!@````(``@`&``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0`!
M``(``0`"``$``@`!``$``0`!`````@`!``$````!`````0`!`/0!```0````
M(````'4::0D```,`R00````````!``4`0P(``!``````````E)&6!@``!P#5
M!```$````'09:0D```8`X`0``!````!R&6D)```%`.P$```0````%&EI#0``
M!`#X!```$````'4::0D```(`R00```````!8JR````````@`````````P"$`
M``````!@JR````````@`````````@"$````````(L"````````@`````````
M"+`@```````8L"````````@`````````0%P```````"XKR````````8````%
M``````````````#`KR````````8````*``````````````#(KR````````8`
M```@``````````````#0KR````````8````D``````````````#8KR``````
M``8````L``````````````#@KR````````8````W``````````````#HKR``
M``````8````Z``````````````#PKR````````8```!!``````````````#X
MKR````````8```!"``````````````!PJR````````4```!0````````````
M```@L"````````4```!@``````````````!`L"````````4```!D````````
M``````!(L"````````4```!7``````````````!@L"````````4```!;````
M``````````#@K2````````<````!``````````````#HK2````````<````"
M``````````````#PK2````````<````#``````````````#XK2````````<`
M```$````````````````KB````````<````&```````````````(KB``````
M``<````'```````````````0KB````````<````(```````````````8KB``
M``````<````)```````````````@KB````````<````+```````````````H
MKB````````<````,```````````````PKB````````<````-````````````
M```XKB````````<````.``````````````!`KB````````<````/````````
M``````!(KB````````<````0``````````````!0KB````````<````1````
M``````````!8KB````````<````2``````````````!@KB````````<````3
M``````````````!HKB````````<````4``````````````!PKB````````<`
M```5``````````````!XKB````````<````6``````````````"`KB``````
M``<````7``````````````"(KB````````<````8``````````````"0KB``
M``````<````9``````````````"8KB````````<````:``````````````"@
MKB````````<````;``````````````"HKB````````<````<````````````
M``"PKB````````<````=``````````````"XKB````````<````>````````
M``````#`KB````````<````?``````````````#(KB````````<````A````
M``````````#0KB````````<````B``````````````#8KB````````<````C
M``````````````#@KB````````<````E``````````````#HKB````````<`
M```F``````````````#PKB````````<````G``````````````#XKB``````
M``<````H````````````````KR````````<````I```````````````(KR``
M``````<````J```````````````0KR````````<````K```````````````8
MKR````````<````M```````````````@KR````````<````N````````````
M```HKR````````<````O```````````````PKR````````<````P````````
M```````XKR````````<````Q``````````````!`KR````````<````R````
M``````````!(KR````````<````S``````````````!0KR````````<````T
M``````````````!8KR````````<````U``````````````!@KR````````<`
M```V``````````````!HKR````````<````X``````````````!PKR``````
M``<````Y``````````````!XKR````````<````[``````````````"`KR``
M``````<````\``````````````"(KR````````<````]``````````````"0
MKR````````<````^``````````````"8KR````````<````_````````````
M``"@KR````````<```!```````````````"HKR````````<```!#````````
M``````"PKR````````<```!$``````````````!(@^P(2(L%'94@`$B%P'0"
M_]!(@\0(PP#_-0J3(`#_)0R3(``/'T``_R4*DR``:`````#IX/____\E`I,@
M`&@!````Z=#_____)?J2(`!H`@```.G`_____R7RDB``:`,```#IL/____\E
MZI(@`&@$````Z:#_____)>*2(`!H!0```.F0_____R7:DB``:`8```#I@/__
M__\ETI(@`&@'````Z7#_____)<J2(`!H"````.E@_____R7"DB``:`D```#I
M4/____\ENI(@`&@*````Z4#_____);*2(`!H"P```.DP_____R6JDB``:`P`
M``#I(/____\EHI(@`&@-````Z1#_____)9J2(`!H#@```.D`_____R62DB``
M:`\```#I\/[___\EBI(@`&@0````Z>#^____)8*2(`!H$0```.G0_O___R5Z
MDB``:!(```#IP/[___\E<I(@`&@3````Z;#^____)6J2(`!H%````.F@_O__
M_R5BDB``:!4```#ID/[___\E6I(@`&@6````Z8#^____)5*2(`!H%P```.EP
M_O___R5*DB``:!@```#I8/[___\E0I(@`&@9````Z5#^____)3J2(`!H&@``
M`.E`_O___R4RDB``:!L```#I,/[___\E*I(@`&@<````Z2#^____)2*2(`!H
M'0```.D0_O___R4:DB``:!X```#I`/[___\E$I(@`&@?````Z?#]____)0J2
M(`!H(````.G@_?___R4"DB``:"$```#IT/W___\E^I$@`&@B````Z<#]____
M)?*1(`!H(P```.FP_?___R7JD2``:"0```#IH/W___\EXI$@`&@E````Z9#]
M____)=J1(`!H)@```.F`_?___R72D2``:"<```#I</W___\ERI$@`&@H````
MZ6#]____)<*1(`!H*0```.E0_?___R6ZD2``:"H```#I0/W___\ELI$@`&@K
M````Z3#]____):J1(`!H+````.D@_?___R6BD2``:"T```#I$/W___\EFI$@
M`&@N````Z0#]____)9*1(`!H+P```.GP_/___R6*D2``:#````#IX/S___\E
M@I$@`&@Q````Z=#\____)7J1(`!H,@```.G`_/___R5RD2``:#,```#IL/S_
M__\E:I$@`&@T````Z:#\____)6*1(`!H-0```.F0_/___R5:D2``:#8```#I
M@/S___\E4I$@`&@W````Z7#\____)4J1(`!H.````.E@_/___R5"D2``:#D`
M``#I4/S___\E.I$@`&@Z````Z4#\____)7*1(`!FD```````````55-(@^PX
MB7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`
MZ!C^__](BS4)D2``2(L]"I$@`$B)\NBB.0``@#U;D2```'4OZ#3]__](A<!(
MB06JH2``#X2N`0``2(G'Z&S\__^+/1:1(`#HX?W__\:`T0@```"+/021(`#H
MS_W__X"(J@0```*+/?*0(`#HO?W__X"(J@0```&+1"0<C7@%2+C_________
M'TAC_T@YQP^'&0$``$C!YP-(C1V1.P``Z`G]__](BWPD$$B)!16A(`"^!0``
M`,<%#J$@``0```!(BQ=(B5@(2(T=9CL``$B#QPA(B5@82(D02(L5=I`@`$B)
M4!"+5"0<@_H!C4H$?AQF#Q]$``!,BP],8\:#Q@%(@\<(.<Y.B4S`^'7J2(L]
MRZ`@`$ACR4B--0$@``!(QT3(^`````"#P@-%,<!(B<'H>OW__X7`B<-T44B+
M/9V@(`!(C6PD).CC^___2(T]KSD``#'`2(GNZ"(9``!(A<!T.DB+/7:@(`#H
M8?O__^@,_?__B=A(BUPD*&1(,QPE*````'5?2(/$.%M=PTB+/4R@(`#HM_W_
M_XG#ZY](BSTTH"``2(7_=!SHDC<``.NS2(TU^8H@`$B-/?4X```QP.B;_/__
M2(T][#@``$B)[NBL&```2(7`2(G'2(D%]Y\@`'2`Z\3H%OO__[\!````Z'S]
M__]F+@\?A```````9I`Q[4F)T5Y(B>)(@^3P4%1,C04Z.```2(T-PS<``$B-
M/:S]____%=Z.(`#T#Q]$``!(C3TICR``2(T%*8\@`%5(*?A(B>5(@_@.=A5(
MBP6FCB``2(7`=`E=_^!F#Q]$``!=PP\?0`!F+@\?A```````2(T]Z8X@`$B-
M->*.(`!52"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!9&.(`!(A<!T#%W_
MX&8/'X0``````%W##Q]``&8N#Q^$``````"`/>&.(```=2=(@SUGCB```%5(
MB>5T#$B+/6J.(`#HW?S__^A(____7<8%N(X@``'SPP\?0`!F+@\?A```````
M2(T]H8D@`$B#/P!U"^E>____9@\?1```2(L%"8X@`$B%P'3I54B)Y?_07>E`
M____05=!5DR-3SA!54%4,<E54TB![)@"``!D2(L$)2@```!(B80DB`(``#'`
M2(GB#Q\`08L$"4V+!`D/R$R)QHG`2,'N($B)!$I,B<!)P>@X2,'H*"4`_P``
M3`G`28GP2,'F"$G!X!B!Y@``_P!%B<!,"<!("?!(B41*"$B#P0A(@_E`=:U(
MC;(``@``9@\?1```2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@
M_TB)0GA(.?)UU4R+!TR+7R!,BT\03(M7&$B+=PA(BTPD"$R)P$R)PDV)Q4C!
MZAM(P>`%2<'M`D@)T$B+%"1(B?.)P$C!XQY)C8P*F7F"6DF-E!.9>8):2`'0
M3(G*3#'22"'R3#'22`'"2(GP2,'H`D&)U$@)PTR)R$R)Y8G;2,'M&T@QV$PA
MP$PQR$@!R$R)X4C!X05(">F)R4@!R$R)P4C!X1Z)Q4P)Z4V)Y4F)[HG)2??5
M2<'N&TDAW4@ARDP)ZDR+;"003XVL*9EY@EI,`>I)B>U)P>4%30GU18GM3`'J
M38GE2<'L`DG!Y1Y!B=9-">Q%B>5)B>Q)]]1,(>A)(<Q,">!,BV0D&$J-G".9
M>8):38GT2<'L&T@!V$R)\TC!XP5,">.)VT@!V$B)ZTC![0)(P>,>08G$2`G=
MB>M,B?5(]]5((=I,(>U(">I(BVPD($B-C"F9>8):3(GE2,'M&T@!RDR)X4C!
MX05(">F)R4@!RDR)\4G![@)(P>$>B=5)"<Y$B?%-B>9)]]9((<A)(=Y,"?!,
MBW0D*$^-K#69>8):28GN2<'N&TP!Z$F)[4G!Y05-"?5%B>U,`>A-B>5)P>4>
M2<'L`D&)QDT)[$6)Y4F)[$GWU$PAZDDAS$P)XDR+9"0P2HV<(YEY@EI-B?1)
MP>P;2`':3(GS2,'C!4P)XXG;2`':2(GK2,'M`DC!XQY!B=1("=V)ZTR)]4CW
MU4@AV$PA[4@)Z$B+;"0X2(V,*9EY@EI,B>5(P>T;2`'(3(GA2,'A!4@)Z8G)
M2`'(3(GQ2<'N`DC!X1Z)Q4D)SD2)\4V)YDGWUD@ARDDAWDP)\DR+="1`3XVL
M-9EY@EI)B>Y)P>X;3`'J28GM2<'E!4T)]46)[4P!ZDV)Y4G!Y1Y)P>P"08G6
M30GL18GE28GL2??43"'H22',3`G@3(MD)$A*C9PCF7F"6DV)]$G![!M(`=A,
MB?-(P>,%3`GCB=M(`=A(B>M(P>T"2,'C'D&)Q$@)W8GK3(GU2/?52"':3"'M
M2`GJ2(ML)%!(C8PIF7F"6DR)Y4C![1M(`<I,B>%(P>$%2`GIB<E(`<I,B?%)
MP>X"2,'A'HG520G.1(GQ38GF2??62"'(22'>3`GP3(MT)%A/C:PUF7F"6DF)
M[DG![AM,`>A)B>U)P>4%30GU18GM3`'H38GE2<'L`DG!Y1Y!B<9-">Q%B>5)
MB>Q)]]1,(>I)(<Q,">),BV0D8$J-G".9>8):38GT2<'L&T@!VDR)\TC!XP5,
M">.)VT@!VDB)ZTC![0)(P>,>08G42`G=B>M,B?5(]]5((=A,(>U(">A(BVPD
M:$B-C"F9>8):3(GE2,'M&T@!R$R)X4C!X05(">E,B?5)P>X"2,'E'HG)20GN
M2`'(1(GU38GFB<%)]]9((>I)(=Y,"?),BW0D<$^-K#69>8):28G.2<'N&TP!
MZDF)S4G!Y05-"?5%B>U,`>I-B>5)P>P"2<'E'D&)UTT)[$6)Y4F)S$GWU$PA
MZ$DA[$P)X$R+9"1X2HV<(YEY@EI-B?Q)P>P;2`'83(G[2,'C!4P)XXG;2`'8
M2(G+2,'I`DC!XQY!B<1("=F)RTR)^4CWT4@AVDPAZ4@)RDB+C"2`````2(V,
M#9EY@EI,B>5(P>T;2`'13(GB2,'B!4@)ZDR)_4G![P)(P>4>B=)(`=%)">],
MB>)$B?U(]])!B<Y((=I((>A("=!(BY0DB````$F-E!69>8):38GU2`'03(GR
M2,'B!4G![1M,">I-B>5)P>P"2<'E'HG230GL2`'02(N4))````!%B>5-B?1!
MB<=)]]1,(>E)(>Q,">%,C:03F7F"6DR)^DC!X@5)`<Q,B?E(P>D;2`G*B=))
M`=1,B?))P>X"2,'B'D2)XTP)\DV)_HG12??632'N2"'(3`GP3(NT))@```!*
MC:PUF7F"6DF)WDG![AM(`>A(B=U(P>4%3`GUB>U(`>A,B?U)P>\"2,'E'D&)
MQDP)_4@QZD$QU$B+E"2@````28V4%:'KV6Y-B?5,`>)-B?1)P>0%2<'M&TT)
M[$6)Y$P!XDF)W$C!ZP))P>0>08G520G<2(GKB>U,,>-(`ZPDL````#'82(N<
M)*@```!(C9P9H>O9;DR)Z4C!Z1M(`<-,B>A(P>`%2`G(B<!(`<-,B?!)P>X"
M2,'@'HG93`GP38GF18GD23'&3`.D)+@```!$,?),C;P5H>O9;DB)RDB)S4C!
M[1M(P>(%2`GJ3(GM2<'M`DC!Y1Z)TDP)[4F)Q4D!UTDQ[42)^HG`1#'K38VL
M'*'KV6Y(B=-)B=1)P>P;2,'C!4P)XXG;20'=2(G+2`.$),````!(P>D"2,'C
M'D6)[D@)RTB)Z4V)]$@QV4G![!M!,<]*C8PXH>O9;DR)\$C!X`5,">")P$@!
MR$B)T4C!Z@)(P>$>08G$2`G1B>I(`Y0DR````$B)W8G;2`.<)-````!(,<U!
M,>U*C:PJH>O9;DR)XDV)Y4G![1M(P>(%3`GJB=)(`=5,B?))P>X"2,'B'D&)
M[4P)\DF)SHG)23'61#'P38GN2(V<`Z'KV6Y,B>A)P>X;2,'@!4P)\(G`2`'#
M3(G@2,'@'DG![`)(`XPDV````$P)X$F)U$&)WDDQQ(G22`.4).````!$,>5-
MB?1(C:PIH>O9;DR)\4G![!M(P>$%3`GAB<E(`>E,B>U)P>T"2,'E'D&)S$P)
M[4F)Q8G`23'M2`.$).@```!$,>M-B>5(C9P:H>O9;DR)XDG![1M(P>(%3`GJ
MB=)(`=I,B?-)P>X"2,'C'D&)U4P)\TF)[HGM23'>1#'Q38GN2(V,"*'KV6Y,
MB>A)P>X;2,'@!4P)\(G`2`'(3(GA2<'L`DC!X1Y!B<9,">%(`ZPD\````$F)
MW$DQS(G;2`.<)/@```!$,>)-B?1)P>P;2(VL%:'KV6Y,B?)(P>(%3`GBB=)(
M`=5,B>I)P>T"2,'B'D&)[$P)ZDF)S8G)23'52`.,)``!``!$,>A-B>5(C9P#
MH>O9;DR)X$G![1M(P>`%3`GHB<!(`<-,B?!)P>X"2,'@'D&)W4P)\$F)UHG2
M23'&2`.4)`@!``!$,?5-B>Y(C:PIH>O9;DR)Z4G![AM(P>$%3`GQB<E(`>E,
MB>5)P>P"2,'E'D&)SDP)Y4F)Q(G`23'L1#'C38GT2`.$)!`!``!(C9P:H>O9
M;DR)\DG![!M(P>(%3`GBB=)(`=I,B>M)P>T"2,'C'D&)U$P)ZTF)[8GM23'=
M2`.L)!@!``!$,>E-B>5(C8P(H>O9;DR)X$G![1M(P>`%3`GHB<!(`<A,B?%)
MP>X"2,'A'D&)Q4P)\4F)WHG;23'.2`.<)"`!``!$,?),C;05H>O9;DR)ZDR)
M[4C![1M(P>(%2`GJB=))`=9,B>))P>P"2,'B'D2)]4P)XDF)S(G)23'41#'@
M28GL2(V<`Z'KV6Y(B>A(P>`%2<'L&T@#C"0H`0``3`G@B<!(`<-,B>A)P>T"
M2,'@'D&)W$P)Z$F)U8G223'%2`.4)#`!``!%,>Y.C:PQH>O9;DR)X4V)YDG!
M[AM(P>$%3`GQB<E)`<U(B>E(P>T"2,'A'D6)[T@)Z4B)Q8G`2#'-2`.$)#@!
M```QZTR)_4B-G!JAZ]EN3(GZ2,'M&TC!X@5(">I,B>5)P>P"2,'E'HG23`GE
M28G,2`':23'LB=.)R44QY4F)W$Z-M"BAZ]EN2(G82<'L&TC!X`5,">!-B?R)
MP$D!QDG![P))P>0>30G\2(GH18GU3`G@2"'"2(GHB>U,(>`)PKC<O!N/28G'
M3`.\)$`!``!,`?E-B>](`<I,B>E)P>\;2,'A!4P)^8G)2`'*2(G92,'K`DC!
MX1Y!B==("=E,B>-("<M)(=Y,B>-%B>1((<M!"=Y(B<-(`YPD2`$``$@!W4R)
M^TD![DR)_4C!XP5(P>T;2`GKB=M)C2P>3(GK2<'M`DC!XQY,">M)B<U!B>Y)
M"=U,(>I)B<V)R4DAW40)ZDF)Q4P#K"10`0``30'L38GU20'43(GR2<'M&TC!
MX@5,">J)TDV-+!1,B?I)P>\"2,'B'DP)^DF)WT6)[$D)UTPA_4F)WXG;22'7
M1`G]28G'3`.\)%@!``!,`?E-B>=(`<U,B>%)P>\;2,'A!4P)^8G)3(U\#0!,
MB?%)P>X"2,'A'DP)\4F)UD2)_4D)SDTA]4F)UHG222'.10GU28G&3`.T)&`!
M``!,`?--C70=`$B)ZTF)[4C!XP5)P>T;3`GKB=M-C2P>3(GC2<'L`DC!XQY)
M"=Q(B<M%B>Y,">-)(=](B<N)R4PAXT$)WTB)PT@#G"1H`0``2`':3(GS20'7
M3(GR2,'K&TC!X@5("=J)TDF-'!=(B>I(P>T"2,'B'D@)U4R)XD&)WT@)ZDDA
MU4R)XD6)Y$@AZD$)U4B)PD@#E"1P`0``2`'13(GZ3`'I38G]2,'B!4G![1M,
M">J)TDR-+!%,B?))P>X"2,'B'DP)\DF)[D2)Z4D)UDPA\TF)[HGM22'61`GS
M28G&3`.T)'@!``!-`?1)B<Y)`=Q(B<M)P>X;2,'C!4P)\XG;38TT'$R)^TG!
M[P)(P>,>3`G[28G718GT20G?32']28G7B=))(=]%"?U)B<=,`[PD@`$``$P!
M_4V-?"T`3(GE38GE2<'M&TC!Y05,">V)[4V-+"](B<U(P>D"2,'E'D@)Z4B)
MW46)[T@)S4DA[DB)W8G;2"'-00GN2(G%2`.L)(@!``!(`>I,B?U)`=9,B?I(
MP>(%2,'M&T@)ZHG228TL%DR)XDG![`)(P>(>20G42(G*08GN3`GB22'52(G*
MB<E,(>)!"=5(B<)(`Y0DD`$``$@!TTR)\DP!ZTV)]4C!X@5)P>T;3`GJB=),
MC2P33(GZ2<'O`DC!XAY,"?I-B>=$B>M)"==,(?U-B>=%B>1)(==$"?U)B<=,
M`[PDF`$``$P!^4F)WT@!S4B)V4G![QM(P>$%3`GYB<E,C7P-`$R)]4G![@)(
MP>4>3`GU28G61(GY20GN32'U28G6B=))(>Y%"?5)B<9,`[0DH`$``$T!]$F)
MSDT!Y4F)S$G![AM)P>0%30GT18GD3XUT)0!)B=Q(P>L"2<'D'DP)XTF)[$6)
M]4D)W$TAYTF)[(GM22'<10GG28G$3`.D)*@!``!,`>)-B>Q)`==,B>I)P>P;
M2,'B!4P)XHG238TD%TB)RDC!Z0)(P>(>2`G12(G:18GG2`G*22'62(G:B=M(
M(<I!"=9(B<)(`Y0DL`$``$@!U4R)^DD![DR)_4C!X@5(P>T;2`GJB=))C2P6
M3(GJ2<'M`DC!XAY,">I)B<U!B>Y)"=5-(>Q)B<V)R4DAU44)[$F)Q4P#K"2X
M`0``3`'K38GU20'<3(GS2<'M&TC!XP5,">N)VTP!XTV)_$G![P))P>0>08G=
M30G\28G730GG3"']28G7B=)-(>=$"?U)B<=,`[PDP`$``$P!^4R-?`T`3(GI
M3(GM2,'M&TC!X05(">F)R4F-+`],B?%)P>X"2,'A'DD)SDR)X4&)[TP)\4@A
MRTR)X46)Y$PA\0G+2(G!2`.,),@!``!(`<I(C0P33(GZ3(G[2,'K&TC!X@5(
M"=J)TDB-'!%,B>E)P>T"2,'A'DP)Z4V)]8G:20G-3"'M38GU18GV22'-1`GM
M28G%3`.L)-`!``!(`X0DV`$``$T![$Z-;"4`2(G528G42<'L&TC!Y05,`?!,
M">6)[4V-9"T`3(G]2<'O`DC!Y1Y,"?U)B<]%B>5)">]-B>Y,(?M)B<^)R4DA
M[T0)^T@!V$R)ZTC!XP5)P>X;3`GSB=M(`=A(B=-(P>H"2,'C'D&)QD@)T[K6
MP6+*28G73`.\).`!``!)`<](B>F)[4@QV4$QS$N-#"=-B?1-B?=)P>\;2<'D
M!4T)_$6)Y$P!X4V)[$G![0))P>0>08G/30GL28G53`.L).@!``!,`>U)B=V)
MVTTQY40QZ$V)_4@!Z$R)_4G![1M(P>4%3`GMB>U(`>A,B?5)P>X"2,'E'D&)
MQ4P)]4F)UDP#M"3P`0``3`'S38GF18GD23'N1#'Q38GN2`'93(GK2<'N&TC!
MXP5,"?.)VT@!V4R)^TG![P)(P>,>08G.3`G[28G73`.\)/@!``!-`?Q)B>^)
M[4DQWT0Q^$V)]TP!X$V)]$G![QM)P>0%30G\18GD3`'@38GL2<'M`DG!Y!Y!
MB<=-">Q)B=5,`ZPD``(``$P![4F)W8G;33'E1#'I38G]2`'I3(G]2<'M&TC!
MY05,">V)[4@!Z4R)]4G![@)(P>4>08G-3`GU28G63`.T)`@"``!,`?--B>9%
MB>1),>Y$,?!-B>Y(`=A,B>M)P>X;2,'C!4P)\XG;2`'83(G[2<'O`DC!XQY!
MB<9,"?M)B==,`[PD$`(``$T!_$F)[XGM23'?1#'Y38GW3`'A38GT2<'O&TG!
MY`5-"?Q%B>1,`>%-B>Q)P>T"2<'D'D&)STT)[$F)U4P#K"08`@``3`'M28G=
MB=M-,>5$,>A-B?U(`>A,B?U)P>T;2,'E!4P)[8GM2`'H3(GU2<'N`DC!Y1Y!
MB<5,"?5)B=9,`[0D(`(``$P!\TV)YD6)Y$DQ[D0Q\4V)[D@!V4R)ZTG![AM(
MP>,%3`GSB=M(`=E,B?M)P>\"2,'C'D&)SDP)^TF)UTP#O"0H`@``30'\28GO
MB>U),=]$,?A-B?=,`>!-B?1)P>\;2<'D!4T)_$6)Y$P!X$V)[$G![0))P>0>
M08G'30GL28G53`.L)#`"``!,`>U)B=V)VTTQY40QZ4V)_4@!Z4R)_4G![1M(
MP>4%3`GMB>U(`>E,B?5)P>X"2,'E'D&)S4P)]4F)UDP#M"0X`@``3`'S38GF
M18GD23'N1#'P38GN2`'83(GK2<'N&TC!XP5,"?.)VT@!V$R)^TG![P)(P>,>
M08G&3`G[28G73`.\)$`"``!-`?Q)B>^)[4DQWT0Q^4V)]TP!X4V)]$G![QM)
MP>0%30G\18GD3`'A38GL2<'M`DG!Y!Y!B<]-">Q)B=5,`ZPD2`(``$P![4F)
MW8G;33'E1#'H38G]2`'H3(G]2<'M&TC!Y05,">V)[4@!Z$R)]4G![@)(P>4>
M08G%3`GU28G63`.T)%`"``!,`?--B>9%B>1),>Y$,?%-B>Y(`=E,B>M)P>X;
M2,'C!4P)\XG;2`'93(G[2<'O`DC!XQY!B<Y,"?M)B==,`[PD6`(``$T!_$F)
M[XGM23'?1#'X38GW3`'@38GT2<'O&TG!Y`5-"?Q%B>1,`>!-B>Q)P>T"2<'D
M'D&)QTT)[$F)U4P#K"1@`@``3`'M28G=B=M-,>5$,>E-B?U(`>E,B?U)P>T;
M2,'E!4P)[4V)]4G![@))P>4>B>U-"?5)B=9,`[0D:`(``$@!Z8G-3`'S38GF
M18GD33'N1#'P28GN2`'82(GK2<'N&TC!XP5,"?.)VT@!V$R)^TG![P)(P>,>
M08G&3`G[28G73`.\)'`"``!-`?Q-B>]%B>U),=]$,?E-B?=(`Y0D>`(``$D!
MS$R)\4G![QM(P>$%00';3`GY3(E?($$!S$B)Z4C![0)(P>$>3`'J28G=2`GI
M3(GU2<'N`DDQS4C!Y1Y$`>9$,>A-B>5,"?5(`=!,B>))P>T;2,'B!4$!Z40!
MT4P)ZDB)=PA,B4\0`=!(B4\800'`2(N$)(@"``!D2#,$)2@```!,B0=U$DB!
MQ)@"``!;74%<05U!7D%?P^B*XO__9BX/'X0``````$%7059!54%455-(@^P(
M2(7_#X2C````3(L]ZG8@`$V%_P^$DP````^V!X3`='(\/71N28G\28/$`4$/
MM@0DA,!T!#P]=>]!*?Q)BQ](A=MT-4F)]4F)_DUCY$R)_0\?`$R)XDR)]DB)
MW^A2X?__A<!U!T*`/",]="](@\4(2(M=`$B%VW7:2(/$"$B)V%M=05Q!74%>
M05_##Q^$``````!%,>3KI`\?`$PI_4J-7",!2,']`T&);0#KS#';Z\AFD%53
M2(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD!&:0,<!(B=Y(B>_H$____TB%
MP'0P2&-4)`1(BP4*=B``2(T$T$B+4`A(A=)(B1!TTF:02(/`"$B+4`A(A=)(
MB1!U\.N^2(M$)`AD2#,$)2@```!U!TB#Q!A;7</H0N'__V:005=!5D%50515
M4TB)\TB)_4B#["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(`<-(B=_H^>#_
M_TB-="0428G$2(GO,<#H=_[__TB%P`^$#@$``$B)QTF)Q>C3X/__23G$#X;B
M````3&-T)!1)P>8##[9%`(3`#X2K`0``/#T/A*,!``!(B>CK#0\?A```````
M@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U''4@`$J-?"`"Z,KA__](A<!)B08/
MA'@!``!(8U0D%$B+!?IT(`!(C4T!2(L4T`^V10`\/8@"=":$P'40ZR!F+@\?
MA```````/#UT$DB#P0$/MD'_2(/"`83`B`)UZL8"/3'`#Q]$```/M@P#B$P"
M`4B#P`&$R77P,<!(BW0D&&1(,S0E*`````^%#@$``$B#Q"A;74%<05U!7D%?
MPP\?`$B#PP$/MD/_28/%`83`08A%_W7LZ\)FD$R+/6%T(`!)@S\`#X2\````
M3(GX,=+K"P\?A```````1(GJ2(/`"$2-:@%(@S@`=>^-<@-(8_9(P>8#BP5?
MA"``A<!T.TR)_^ACX?__2(7`2(D%$70@``^$?0```$UCQ4B)P4Z--,4`````
M2L=$P0@`````1(EL)!3ID?[__V:02(GWQP43A"```0```.B.X/__2(7`=$--
M8\5,B?Y(B<=.C33%`````$R)1"0(3(GRZ!OA__],BT0D"$B)P4B)!:1S(`#K
MI3'`Z7C^__^^$````$4Q[>EA____N/_____IWO[__^CWWO__#Q^``````$%6
M055!5%532('LH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74Q
M2(N$))@```!D2#,$)2@````/A3$!``!(@<2@````6UU!7$%=05[#9BX/'X0`
M`````.@KWO__2(7`28G$=,))B>5,B>?H>.#__TB%P$B)PW0U#[93$[@N````
MB<$IT75!#[93%(72=-DIT`^$P0```/?8A<!U+TR)Y^A#X/__2(7`2(G#=<M,
MB>?HL][__TB)[^@+WO__Z67___]F#Q]$``"%R72<2(/#$TB)[^@`WO__2(G?
M28G&Z/7=__]!C7P&`DAC_^@XW___2(T-51L``$F)QDB)QTF)V4F)Z$C'PO__
M__^^`0```#'`Z(+@__^_`0```$R)ZDR)]NA2W?__@_C_3(GW=!"+1"08)0#P
M```]`$```'0JZ-7<__],B??HK=S__^D8____#Q^$```````/MD,5Z3C___\/
M'X``````Z(O^___KU.ATW?__#Q]``%-(B?N+/<9Q(`#HD=[__TB-D``"``!(
MB=Z_`0```.BMW___A<!T"3'`6\,/'T0``(L]FG$@`.AEWO__BX`8`@``)0#P
M```]`$```'0=BSU]<2``Z$C>__^+@!@"```E`/```#T`H```=;U(B=^^`@``
M`.@9W___A<`/E,`/ML!;PP\?1```9BX/'X0``````$%5051)B?Q54TB-/3H:
M``!)B?6Z_P\``$B![!@0``!(B>9D2(L$)2@```!(B80D"!```#'`Z`;<__^%
MP'YRC5#_2(GC2&/J@#PL`'1;2&/H2(GJOB\```!(B=_H0-W__TB%P'1+BSW5
M<"``Z*#=__](B>E(B=I,B>9(B<?HG][__TB+A"0($```9$@S!"4H````=3=(
M@<08$```6UU!7$%=PV8/'T0``(72=:0/'T``BSV*<"``Z%7=__],B>I,B>9(
MB<?H5]S__^NVZ!#<__](@^P(BSUF<"``Z#'=__](BQ7Z;R``2(T-6QL``$B-
M-649``!(B<=(@\0(Z5#=__](@^P(BSTV<"``Z`'=__](B<?HN?___XL](W`@
M`.CNW/__3(T%QQH``$B-%3`4``!(C34^&0``13')2(G'2(/$"$R)P>E7W?__
M#Q^``````%532('L*"```&1(BP0E*````$B)A"08(```,<#H[]K__TR-#=T8
M``!(C0T+&0``08G`N@$0```QP+X!````2(GGZ/K=__^%P'AN2(VL)!`0``"Z
M`!```$B)YTB)[NB.VO__A<!(B<-X3XUX`4AC_^A<W/__2(7`2(G!=!A(8]M(
MB>Y(B<=(B=KH$]S__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'422('$
M*"```%M=PP\?0``QR>O8Z,_:__\/'T0``&8N#Q^$``````#I*____Y!F+@\?
MA```````05=!5D%5051)B?154TB)^TB-/5$8``!(@>PH$```9$B+!"4H````
M2(F$)!@0```QP$B-="0,Z/7W__^^+P```$B)WTB)Q>B%VO__2(7`=#U(C3T:
M&```2(G>,<#H#_G__TB)V$B+C"08$```9$@S#"4H````#X6)`0``2('$*!``
M`%M=05Q!74%>05_#2(G?Z`O:__](C37B%P``3(GG08G&Z#G<__](A<!)B<=T
MH4&#Q@%!@#\`3(TMP!<``$R-9"00#X3E````#Q^``````$B%[7033(G^2(GO
MZ+#:__^%P`^$I@```$R)_^BPV?__B<)(F$&`?`?_+W47#Q]``(/J`4ACPD&`
M?`?_+T'&!`<`=.U$`?*!^O\/```/CR[___](@^P(2(T-21@``$R-#4P7``!3
M38GXN@`0``"^`0```$R)YS'`Z!3<__^+/;YM(`#HB=K__TB-D``"``!,B>:_
M`0```.C5V/__A<!:674=BSV9;2``Z&3:__^+@!@"```E`/```#T`@```=$DQ
M_TR)[NA(V___2(7`28G'#X2L_O__08`_``^%(O___TB%[7032(T]K!8``+D"
M````2(GN\Z9TR$R-/9D6``"Z`0```.D\____O@$```!,B>?H[-K__X7`=:9(
MC3V"%@``3(GFZ'GW__],B>?H4=G__^E@_O__Z*?8__\/'X``````#[8/2(GX
MA,ET&$B-5P%FD(#Y+P^V"D@/1,)(@\(!A,EU[O/#9I!F+@\?A```````55-(
M@^P(2(7_=%4/MB](B?M`A.UT2NA%V/__2(U4`_](.=-R%.LG9@\?A```````
M2(/J`4@YTW0?@#HO=/+K!8`Z+W1`2(/J`4@YTW+R2#G3=3(/'T0``$"`_2]U
M<V:0OP(```#H1MG__TB%P'19NBX```!FB1!(@\0(6UW#9I"`.B]U"4B#Z@%(
M.=-R\D@IVDB-0@)(/0`0``!W*TB-/8QL(`!(B=Y(@\(!N0`0``#H6]G__TB#
MQ`A(C05P;"``6UW##Q]$``!(@\0(,<!;7<-(@\0(2(T]9!4``%M=Z2W8__\/
M'P!F+@\?A```````4TB-/4H5``!(@^Q`9$B+!"4H````2(E$)#@QP$B+!9T6
M``!(C5PD#$B)1"002(L%E!8``$B)1"082(L%D!8``$B)1"0@2(L%C!8``$B)
M1"0H#[<%B!8``&:)1"0P,<#H7/7__TB-/?`4```QP.A.]?__2(T]ZA0``#'`
MZ$#U__](C3WE%```,<#H,O7__TB-/=X4```QP.@D]?__2(T]X!0``#'`Z!;U
M__](C3V'%```,<#H"/7__TB-/=`4```QP.CZ]/__2(T]S!0``#'`Z.ST__](
MC3W(%```,<#HWO3__TB-/5@4```QP.C0]/__2(T]MA0``#'`2(G>Z/_S__](
MA<!T$4B-/8P4``!(B<8QP.@I]?__2(T]H!0``#'`2(G>Z-CS__](A<!T$4B-
M/9P4``!(B<8QP.@"]?__2(T]EA0``#'`2(G>Z+'S__](A<!T/$B-/=T3``!(
MB<8QP.C;]/__2(TUFQ0``$B-/0`4```QP.C&]/__2(M$)#AD2#,$)2@```!U
M8TB#Q$!;PTB-/504```QP$B)WNA?\___2(7`=!I(C3WB$P``2(G&,<#HB?3_
M_^NL#Q^``````$B-="0A2(T],!0``+D*````\Z9UD$B-="0K2(T]KA,``#'`
MZ%CT___I>/___^B.U?__#Q]``&8N#Q^$``````!(@^P89$B+!"4H````2(E$
M)`@QP(L%MFD@`(/X_W092(M,)`AD2#,,)2@```!U14B#Q!C##Q]``$B-="0$
M2(T]2Q,``#'`Z+7R__](A<!T(`^V$(#Z,`^5P(32#Y7"(=`/ML")!6=I(`#K
MM`\?1```,<#K[.@'U?__#Q^``````$B#[`CH!]7__XG'Z+#4__](A<!T"TB+
M`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%454B)_5-(C3U+$P``2(/L$&1(
MBP0E*````$B)1"0(,<!(C70D!.@D\O__2(7`2(GN=#R`.`!(B<-T-$B)Q^@L
MU___2(7`=#=(BT0D"&1(,P0E*`````^%AP```$B#Q!!;74%<PV8N#Q^$````
M``!(C3WB$@``,<#H$O/__^O)2(GOZ#C4__](B=])B<3H+=3__TF-?`0"Z'/5
M__](@^P(3(T-]A$``$B-#><2``!32,?"_____TB)QTF)Q$F)Z+X!````,<#H
MM-;__TB-/882``!,B>8QP.BS\O__6%KI9?___^CGT___#Q^``````$%7059!
M54%428G]55-(C3V$$0``2('LB($``&1(BP0E*````$B)A"1X@0``,<!(C050
M$@``3(UD)"Q(QT0D0`````!(QX0DF`````````!(QT0D8`````!(B40D,$B-
M!3(1``!,B>9(B40D.$B-!;T1``!(B40D<$B-!:H1``!(B40D>$B-!?\1``!(
MB80D@````$B-!:P1``!(B80DB````$B-!>D1``!(B80DD````$B-!<$1``!(
MB40D4$B-!=(1``!(B40D6#'`Z)#P__](A<!T"8`X``^%8@0``#'`Z/O]__](
MA<!(B<,/A&\$``!(B=_HU]+__TB-?``!Z!W4__^`.P!)B<9T-TR-/8T1``!,
MB?4/'P!$#[8#2(GO,<!,B?E(Q\+_____O@$```!(@\,!2(/%`NA3U?__@#L`
M==9(C6PD<$B-/>(0``#K#4B#Q0A(BWT`2(7_=#,QP$R)YNCY[___2(7`2(G#
M=.&`.`!TW$B)Q^CT]/__A<!TT$B)W^CXTO__2(7`28G'=5!(BUPD,#'MZQL/
M'X``````@\4!2&/%2(M<Q#!(A=L/A$P!``"`.P`/A$,!``!(B=_HJ_3__X7`
M=-=(B=_HK]+__TB%P$F)QW3'#Q^``````$R)_^CHT?__3(GQBS%(@\$$C9;_
M_O[^]]8A\H'B@("`@'3HB=;![A#WPH"````/1-9(C7$"2`]$SHG60`#62(/9
M`TPI\8V<"`0$``!(8]M(B=_HZ=+__TB)Q4B-!6P0``!!5DR-#68/``!(C0U3
M$```38GX4$C'PO____^^`0```$B)[S'`Z"74__^^P`$``$B)[^BXT/__@_C_
M05A!60^$BP```(L]M64@`.B`TO__2(V0``(``$B)[K\!````Z)S3__^%P$&)
MQ@^$H0```$F+30!(BSW&92``2(T5UQ```$F)Z+X!````,<`QV^B>T___2(N,
M)'B!``!D2#,,)2@```!(B=@/A6,)``!(@<2(@0``6UU!7$%=05Y!7\-FD$4Q
M_^G8_O__#Q^$``````#HZ\___T2+"$&#^1$/A&/___])BTT`2(L]4V4@`$B-
M%200``!)B>B^`0```#'`,=OH*]/__^N+9@\?A```````BSWJ9"``Z+71__^+
M@!@"```E`/```#T`0```#X4^____BSW)9"``Z)31__]$B[@<`@``Z&C0__]!
M.<</A1[___^+/:ED(`#H=-'__XN`&`(``"7_`0``/<`!```/A?W^__](B=_H
M9M'__TB-/;,.``!(B<-,B>8QP.B2[?__2(7`#X3Q`0``2(G'Z*'0__])BWT`
M2(G&Z$7U__](A<!)B<0/A-$!``!,B>?HT<___X/X`WX\2&/02(T]I`X``+D%
M````28UT%/SSIG4D@_@$#X37!@``@^@$2)A!@'P$_R\/A,8&``!F+@\?A```
M````,<#H&?K__X7`=14Q]DR)Y^AKT?__A<")!"0/A7$!``!(C34`#@``2(T]
M@0T``$R-)7L.```QP$R-+3(-``#H'>[__^C8SO__051,C0T?#0``4$B-#3(.
M``!(Q\+_____28GHO@$```!(B=\QP.C>T?__6%KK368N#Q^$``````#H.\[_
M_X,X$75+Z)'.__]!@\8!2(/L"$B-#?L-``!!5$%638GI4$F)Z$C'PO____^^
M`0```$B)WS'`Z)'1__](@\0@OL`!``!(B=_H(,[__X/X_W2K2(GOZ-/-__](
MC3UT#```2(G>,<#H<NW__TB)W^C:^?__Z9?]__\/'T0``$B)QTB)!"3HQ/G_
M_TB+!"1(B<?H*,___TB)P^ER_?__O0$```!(C3T-#0``ZQ)FD$ACQ8/%`4B+
M?,102(7_="DQP$R)YNC6Z___2(7`=.&`.`!TW$B)Q^CDSO__2(7`2(G#=,SI
M2/O__[\-````2(T=R0P``.AFS___28G&Z4G[__]F#Q]$``!-BV4`Z2;^__],
MC;0D<`$``+H"````2,?&[O___T&)QXG'Z''0__^Z!@```$R)]D2)_^BQSO__
M@+PD<`$```!U#H"\)'$!``!##X2F!0``BSPD,=(Q]DR-K"2@````Z#70__^X
MB:O-[TC'A"2@`````2-%9TC'A"2X````=E0R$$B)A"2H````N/[<NIA(QX0D
MR`````````!(B80DL````+CPX=+#2,>$)-``````````2(F$),````!)C44X
MQX0D&`$```````!(B40D$&8N#Q^$``````"+/"2Z`(```$R)]N@`SO__A<!)
MB<1!B<`/CK,!``!(B[0DR````$ECQ(T4QD@YU@^'BP$``$B+M"30````2,'H
M'4B)E"3(````2`'P2(F$)-````!(8X0D&`$``(7`#X1,`0``0;A`````2(M4
M)!!,B?9!*<!%.<1%#T[$2(T\`DECR$B)RDF)STB)3"0(Z+W-__^+A"08`0``
M1`'X@_A`B80D&`$```^%4____T6)X$R)[T4I^$R+?"0(1(E$)!SHJ]+__T2+
M1"0<30'W#Q\`08/X/P^.I0```$&-0,")1"0<P>@&08G$B40D"$F#Q`%)P>0&
M30'\9@\?A```````28L'3(GO28/'0$B)A"38````28M'R$B)A"3@````28M'
MT$B)A"3H````28M'V$B)A"3P````28M'X$B)A"3X````28M'Z$B)A"0``0``
M28M'\$B)A"0(`0``28M'^$B)A"00`0``Z`72__]-.?QUD(M$)`A$BT0D','@
M!D$IP$B+?"0026/0N4@```!,B?Y$B40D".BGS/__1(M$)`A$B80D&`$``.E5
M_O__#Q]$``!-B??I&/___P\?A```````2(N,)-````!(C7$!Z6S^__^+/"3H
MU\O__TR+I"3(````3(NT)-````!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z
M.`^/C@(``+@X````*=!(8]*#^`A)C505.`^#M@(``*@$#X5G`P``A<!T"Z@"
MQ@(`#X5K`P``3(GP3(GO1(BT)!,!``!(P>@81(BD)!<!``!,C;PD(0$``(B$
M)!`!``!,B?!,C2V4"0``2,'H$(B$)!$!``!,B?!,C;0D:`$``$C!Z`B(A"02
M`0``3(G@2,'H&(B$)!0!``!,B>!(P>@0B(0D%0$``$R)X$C!Z`B(A"06`0``
MZ+70__](BX0DH````$B)PHB$)",!``!(P>H81`^VPHB4)"`!``!(B<)(P>H0
MB)0D(0$``$B)PDB+A"2H````2,'J"(B4)"(!``!(B<*(A"0G`0``2,'J&(B4
M)"0!``!(B<)(P>H0B)0D)0$``$B)PDB+A"2P````2,'J"(B4)"8!``!(B<*(
MA"0K`0``2,'J&(B4)"@!``!(B<)(P>H0B)0D*0$``$B)PDB+A"2X````2,'J
M"(B4)"H!``!(B<*(A"0O`0``2,'J&(B4)"P!``!(B<)(P>H0B)0D+0$``$B)
MPDB+A"3`````2,'J"(B4)"X!``!(B<*(A"0S`0``2,'J&(B4)#`!``!(B<)(
MP>H0B)0D,0$``$B)PDB-A"1``0``2,'J"(B4)#(!``!(B00D28G$Z0@```!%
M#[8'28/'`4R)YS'`3(GI2,?"_____[X!````28/$`NC;R___33GF==9(C04O
M"```QH0D:`$```!0_W0D"$B-#><'``!,C0W4!@``O@$```!)B>A(Q\+_____
M2(G?,<#HF\O__UE>Z1GZ__]-BVT(387M#X0W^?__3(GOZ+_(__](@_@##X8E
M^?__28UT!?Q(C3V0!P``N04```#SIDT/1.7I"?G__[A`````2&/**=!)C4P-
M.(G"=`\QP(G&@\`!.=#&!#$`<O-,B>_HK\[__TF-53BY!P```#'`2(G7\TBK
MZ6']__^)P4C'`@````!(QT0*^`````!(C4H(2(/A^$@IR@'0@^#X@_@(#X(V
M_?__@^#X,=*)UH/""#G"2,<$,0````!R[^D;_?__@+PD<@$``$$/A4SZ__^`
MO"1S`0``0P^%/OK__X"\)'0!``!(#X4P^O__@+PD=0$``$4/A2+Z__]$BSPD
MN@(```!(Q\;&____1(G_Z%/*__^Z*0```$R)]D2)_^B3R/__2(T%S`8``%!!
M5NFB_O__#Q]``,<"`````,=$`OP`````Z97\__\Q_V:)?`+^Z8G\___HC,?_
M_V:09BX/'X0``````$%6055!5%532(/L$(L]SEL@`&1(BP0E*````$B)1"0(
M,<!,C6PD!.B$R/__BSVN6R``2(G#Z';(__\/MH"X````2(T]*P4``$R)[HB#
MN0```#'`Z*CD__](A<!T"8`X,0^$J@(``#'`Z)/O__^+/6U;(`#H.,C__TB-
M-0L&``"Y"P```+H!````2(G'Z-_'__](A<`/A+<```"#/:]K(``!2(M`$$R+
M8"@/CJ(````Q[;L!````ZS,/'X0``````$F+=A!(BP5]:R``2&/32(L\T.B)
MQ___A<!U98L%;VL@`(/#`8/%`3G8?EN+/>]:(`#HNL?__S')2&/53(GF2(G'
MZ(K(__](A<!T-4R+,$&+1@PE``0@`#T`!```=**+/;Q:(`#HA\?__TR)]KD"
M````,=)(B<?HE<;__TB)QNN$BP4*:R``C5#_.>H/A'\!``"+/8E:(`#H5,?_
M_TB--2P%``"Y`P```+H!````2(G'Z/O&__](A<!(B<-T-4B+0!"+/5E:(`!(
MBRCH(<?__TB-%?L$``!(B<=(B>[H'\;__TB+0Q!(BQCV0PY`#X7*`0``BSTH
M6B``Z//&__](C372!```N0,```"Z`0```$B)Q^B:QO__2(7`2(G#=#U(C3U<
M`P``,<!,B>[H$>/__TB%P$B)Q0^$50$``$B+0Q"+/=M9(`!(BQCHH\;__TB)
MZDB)QTB)WNBEQ?__BSV_62``Z(K&__](C35K!```N@$```!(B<?HEL;__XL]
MH%D@`$B)P^AHQO__2(T57@0``$B)WDB)Q^AFQ?__BSV`62``Z$O&__](C3W,
M`@``QH"Y`````$R)[C'`Z(/B__](A<!(B<-(B07.:2``#X20````OL`!``!(
MB=_H,\3__XU0`8/Z`78)@_@1#X7N````2(M$)`AD2#,$)2@````/A=4```!(
M@\006UU!7$%=05[#D(/X`0^.>/[__[L!````9I"+/?I8(`"#PP'HPL7__TR)
MYDB)Q^CWP___.1U1:2``?]_I2_[__V8N#Q^$``````"`>`$`#X13_?__Z4?]
M__^02(L](6D@`.AT\/__2(7`2(G#2(D%'VD@``^%4?___TB-/4H$```QP.B3
MQ?__#Q\`2(L%\6@@`(L]@U@@`$B+*$B+0Q!(BQCH1,7__TB)[DB)W^@IY___
MZ9_^__^+/5Y8(`#H*<7__TB)WDB)Q^A^Q?__Z1O^___HY,/__XG!2(L%HV@@
M`$B-/0P$``!(B=I(BS`QP.@GQ?__#Q^``````%532(G]2(/L".A"Z___#[8(
MA,ET3DB-4`%(B<,/'T``@/DO#[8*2`]$VDB#P@&$R77N,<#H!^[__TB%[70>
MA<!T&H!]``!T%$B--3X"``!(B=_H"<;__T@YV'0,2(/$"%M=PTB)P^O*2(/$
M"$B)[UM=Z5KD__]F+@\?A```````2(T%@5<@`$B%P'0,2(L(Z;S#__\/'T``
M,<GIL</__Y!!5T%608G_055!5$R-):92(`!52(TMIE(@`%-)B?9)B=5,*>5(
M@^P(2,']`^C7P?__2(7M="`QVP\?A```````3(GJ3(GV1(G_0?\4W$B#PP%(
M.=UUZDB#Q`A;74%<05U!7D%?PY!F+@\?A```````\\,``$B#[`A(@\0(PP``
M``$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!5
M4T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E
M<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP,S<`+64`+2T``````````%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S
M92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL
M96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F
M<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@
M/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E
M="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q
M<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E
M860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<
M;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\
M("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U
M;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&
M2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER
M95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[
M8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG
M+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N
M)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*```````!&P,[[````!P```!(@O__.`$```B&__]@`0``
M&(;__R@&``!(B/__"`$``'B)__]X`0``R*#__\@!``"(H?__%`(```BB__]`
M`@``6*3__XP"``#8I?__T`(``&BF___P`@``.*?__RP#``!HI___1`,``+BG
M__]<`P``B*C__X@#``"8J/__G`,``*BJ___\`P``V*K__Q`$``#(J___7`0`
M`,BM__^`!```2*[__YP$``!XKO__N`0``&BO___X!```R+O__[`%``"(O___
M]`4```C`__]8!@``*,#__W`&``"8P/__N`8````````4``````````%Z4@`!
M>!`!&PP'")`!!Q`4````'````#B'__\K```````````````4``````````%Z
M4@`!>!`!&PP'")`!```D````'`````B!___``P````X01@X82@\+=PB``#\:
M.RHS)"(`````%````$0```"@A/__"```````````````3````%P```#XA___
M1A<```!"#A"/`D(.&(X#1@X@C01"#BB,!4,.,(8&00XX@P='#M`%`Q\7"@XX
M00XP00XH0@X@0@X80@X00@X(00L```!(````K````/B>__^^`````$(.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)\"@XX1`XP00XH0@X@0@X8
M0@X00@X(20L`*````/@```!LG___?@````!!#A"&`D$.&(,#1PXP`FT*#AA!
M#A!!#@A!"P!(````)`$``,"?__])`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+0````'`!
M``#$H?__?`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!
M#BA!#B!"#AA"#A!"#@A+"P`<````M`$```"C__^!`````$$.$(,":0H."$8+
M`E`."#@```#4`0``<*/__]``````0@X0C0)"#AB,`T0.((8$00XH@P56#L`@
M`GP*#BA!#B!!#AA"#A!"#@A'"Q0````0`@``!*3__S``````1`X09PX(`!0`
M```H`@``'*3__TD`````1`X0?0X(`"@```!``@``5*3__\$`````00X0A@)!
M#AB#`T<.P$`"J`H.&$$.$$$."$4+$````&P"``#XI/__!0````````!<````
M@`(``/2D__\)`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!U$.
MX"`"9`H..$$.,$$.*$(.($(.&$(.$$(."$$+`ID.Z"!/#O`@>0[H($$.X"``
M```0````X`(``*2F__\D`````````$@```#T`@``P*;__^,`````00X0A@)!
M#AB#`T0.(`)U"@X800X000X(0PMY"@X82`X000X(1@M$"@X80PX000X(00M$
M#AA(#A!!#@@@````0`,``&2G___R`0```$$.$(,"2PY0`X(!"@X000X(00L8
M````9`,``$"I__]Y`````$0.(&\*#@A%"P``&````(`#``"DJ?__)`````!$
M#A!8"@X(1`L``#P```"<`P``N*G__^D`````0@X0C`)!#AB&`T0.((,$2PXP
M`D\*#B!!#AA!#A!"#@A+"W$..$\.0&X..$$.,`"T````W`,``&BJ__]4#```
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!TX.P(,"`R@"#LB#`E(.
MT(,":`[(@P)"#L"#`@)T"@XX00XP00XH0@X@0@X80@X00@X(0PL#B@$.R(,"
M2`[0@P)A#LB#`D$.P(,"8P[(@P))#M"#`D(.V(,"1`[@@P)=#L"#`@/'!0[(
M@P)$#M"#`F@.R(,"00[`@P(#+@$*#LB#`D(.T(,"20L`0````)0$```0MO__
MN0,```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1`Y``[H""@XP00XH00X@
M0@X80@X00@X(0@LP````V`0``(RY__]V`````$$.$(8"00X8@P-'#B`"5PH.
M&$$.$$$."$$+20X81`X000X(+`````P%``#H?___)`(```!!#A"&`D$.&(,#
M1`Y0`[0!"@X800X000X(00L`````%````#P%``"HN?__'P``````````````
M1````%0%``"PN?__90````!"#A"/`D(.&(X#10X@C01"#BB,!4@.,(8&2`XX
M@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`$````)P%``#8N?__`@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,`A````````@"$`
M``````````````````````````````````````````````````$`````````
M`0`````````!`````````-\!`````````0````````#J`0````````$`````
M````]`$````````!`````````$,"`````````0````````"1`P````````P`
M````````J!H````````-`````````!19````````&0````````!8JR``````
M`!L`````````"``````````:`````````&"K(```````'``````````(````
M`````/7^_V\`````F`(````````%`````````"`-````````!@````````"0
M`P````````H``````````@4````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````(!4````````'`````````'`3````````
M"`````````"P`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````\!(```````#___]O``````(`
M````````\/__;P`````B$@```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(BK(```````````````````
M`````````-8:````````YAH```````#V&@````````8;````````%AL`````
M```F&P```````#8;````````1AL```````!6&P```````&8;````````=AL`
M``````"&&P```````)8;````````IAL```````"V&P```````,8;````````
MUAL```````#F&P```````/8;````````!AP````````6'````````"8<````
M````-AP```````!&'````````%8<````````9AP```````!V'````````(8<
M````````EAP```````"F'````````+8<````````QAP```````#6'```````
M`.8<````````]AP````````&'0```````!8=````````)AT````````V'0``
M`````$8=````````5AT```````!F'0```````'8=````````AAT```````"6
M'0```````*8=````````MAT```````#&'0```````-8=````````YAT`````
M``#V'0````````8>````````%AX````````F'@```````#8>````````1AX`
M``````!6'@```````&8>````````=AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````!`7````````$=#
M0SH@*$1E8FEA;B`V+C0N,"TR*2`V+C0N,"`R,#$W,#<R-```+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1A=&$N<F5L+G)O`"YD>6YA;6EC
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````X`@```````#@"````````'```````````````````
M``$````````````````````3````!P````(`````````5`(```````!4`@``
M`````"`````````````````````$````````````````````(0````<````"
M`````````'0"````````=`(````````D````````````````````!```````
M`````````````#0```#V__]O`@````````"8`@```````)@"````````^```
M```````%``````````@````````````````````^````"P````(`````````
MD`,```````"0`P```````)`)````````!@````$````(`````````!@`````
M````1@````,````"`````````"`-````````(`T````````"!0``````````
M`````````0```````````````````$X```#___]O`@`````````B$@``````
M`"(2````````S``````````%``````````(``````````@````````!;````
M_O__;P(`````````\!(```````#P$@```````(``````````!@````(````(
M````````````````````:@````0````"`````````'`3````````<!,`````
M``"P`0````````4`````````"``````````8`````````'0````$````0@``
M```````@%0```````"`5````````B`4````````%````&`````@`````````
M&`````````!^`````0````8`````````J!H```````"H&@```````!<`````
M```````````````$````````````````````>0````$````&`````````,`:
M````````P!H```````#``P``````````````````$``````````0````````
M`(0````!````!@````````"`'@```````(`>````````"```````````````
M``````@`````````"`````````"-`````0````8`````````D!X```````"0
M'@```````((Z```````````````````0````````````````````DP````$`
M```&`````````!19````````%%D````````)````````````````````!```
M`````````````````)D````!`````@`````````@60```````"!9````````
M6#\```````````````````@```````````````````"A`````0````(`````
M````>)@```````!XF````````.P````````````````````$````````````
M````````KP````$````"`````````&B9````````:)D```````#@!0``````
M````````````"````````````````````+D````.`````P````````!8JR``
M`````%BK````````"`````````````````````@`````````"`````````#%
M````#P````,`````````8*L@``````!@JP````````@`````````````````
M```(``````````@`````````T0````$````#`````````&BK(```````:*L`
M```````(````````````````````"````````````````````-8````!````
M`P````````!PJR```````'"K````````$P```````````````````!``````
M``````````````#C````!@````,`````````B*L@``````"(JP```````$`"
M````````!@`````````(`````````!``````````B`````$````#````````
M`,BM(```````R*T````````X`@``````````````````"``````````(````
M`````.P````!`````P``````````L"````````"P````````(```````````
M``````````@```````````````````#R````"`````,`````````(+`@````
M```@L````````(@0```````````````````@````````````````````]P``
M``$````P````````````````````(+`````````E````````````````````
M`0`````````!``````````$````#`````````````````````````$6P````
C``````$```````````````````$`````````````````````
